# C++ Google code style checker(Naming and Comments)
# Author
 Stanislav Dzundza
# How to use
- [--fix| --verify | -f | -v]  [-f | -d | -p]  [path_to_file | path_to_dir]
- -f - file formatting
- -d - directory formatting
- -p - project formatting